summaryrefslogtreecommitdiffstats
path: root/src/formula.cpp
diff options
context:
space:
mode:
authorDimitri van Heesch <dimitri@stack.nl>2002-02-24 18:57:25 (GMT)
committerDimitri van Heesch <dimitri@stack.nl>2002-02-24 18:57:25 (GMT)
commit837e4e86e7d2735cd7106efec6e4512db82d5e7a (patch)
tree81d72027898b1a75221b9ca82b04075277821a9f /src/formula.cpp
parentfa7e820834f7e7648a24accbbaa998092034c80f (diff)
downloadDoxygen-837e4e86e7d2735cd7106efec6e4512db82d5e7a.zip
Doxygen-837e4e86e7d2735cd7106efec6e4512db82d5e7a.tar.gz
Doxygen-837e4e86e7d2735cd7106efec6e4512db82d5e7a.tar.bz2
Release-1.2.14-20020224
Diffstat (limited to 'src/formula.cpp')
-rw-r--r--src/formula.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/formula.cpp b/src/formula.cpp
index 32e16ba..a9541c8 100644
--- a/src/formula.cpp
+++ b/src/formula.cpp
@@ -1,5 +1,5 @@
/******************************************************************************
- *
+ i
*
*
* Copyright (C) 1997-2002 by Dimitri van Heesch.
@@ -85,7 +85,7 @@ void FormulaList::generateBitmaps(const char *path)
for (fli.toFirst();(formula=fli.current());++fli)
{
QCString resultName;
- resultName.sprintf("form_%d.gif",formula->getId());
+ resultName.sprintf("form_%d.png",formula->getId());
// only formulas for which no image exists are generated
QFileInfo fi(resultName);
if (!fi.exists())
@@ -116,7 +116,7 @@ void FormulaList::generateBitmaps(const char *path)
for (;(pagePtr=pli.current());++pli,++pageIndex)
{
int pageNum=*pagePtr;
- msg("Generating image form_%d.gif for formula\n",pageNum);
+ msg("Generating image form_%d.png for formula\n",pageNum);
char dviArgs[4096];
QCString formBase;
formBase.sprintf("_form%d",pageNum);
@@ -297,9 +297,9 @@ void FormulaList::generateBitmaps(const char *path)
dstImage.setPixel(x,y,QMIN(15,(c*15)/(16*10)));
}
}
// save the result as a gif
QCString resultName;
- resultName.sprintf("form_%d.gif",pageNum);
+ resultName.sprintf("form_%d.png",pageNum);
// the option parameter 1 is used here as a temporary hack
// to select the right color palette!
dstImage.save(resultName,1);
@@ -320,8 +320,8 @@ void FormulaList::generateBitmaps(const char *path)
// remove the latex file itself
if (!formulaError) thisDir.remove("_formulas.tex");
// write/update the formula repository so we know what text the
- // generated gifs represent (we use this next time to avoid regeneration
- // of the gifs, and to avoid forcing the user to delete all gifs in order
+ // generated pngs represent (we use this next time to avoid regeneration
+ // of the pngs, and to avoid forcing the user to delete all pngs in order
// to let a browser refresh the images).
f.setName("formula.repository");
if (f.open(IO_WriteOnly))
@@ -297,9 +297,9 @@ void FormulaList::generateBitmaps(const char *path)
}
}
- // save the result as a gif
+ // save the result as a png
QCString resultName;